<?php

/**
 * Social Contact Form Functions
 */

// Is SBF ultimate installed?
if ( ! function_exists( 'is_scf_ultimate' ) ) {
	function is_scf_ultimate() {
		return apply_filters( 'is_scf_ultimate', false );  
	}
}
 
// check is setup completed
if ( ! function_exists( 'scf_is_setup_run' ) ) {
	function scf_is_setup_run() {
		$is_setup = get_option( 'scf-setup-run' );
		return $is_setup == true;
	}
}


// scf option
if ( ! function_exists( 'scf_get_option' ) ) {
	function scf_get_option( $option_name, $default = null ) {
		$option_name_prefix = explode( '/', $option_name )[0];
		$option_name_suffix = explode( '/', $option_name )[1] ?? '';

		$option = get_option( 'scf_' . $option_name_prefix, $default );

		if ( isset( $option_name_suffix ) && ! empty( $option_name_suffix ) ) {
			$option = $option[ $option_name_suffix ] ?? $default;
		}

		if ( ( empty( $option ) || $option == null ) ) {
			$default_options = \WPPOOL\SCF\App::options();
			$option          = $default_options[ $option_name_prefix ] ?? $default;

			if ( isset( $option_name_suffix ) && ! empty( $option_name_suffix ) ) {
				$option = $option[ $option_name_suffix ] ?? $default;
			}
		}

		return $option;
	}
}

// scf options
if ( ! function_exists( 'scf_get_options' ) ) {
	function scf_get_options() {
		$options = \WPPOOL\SCF\App::options();

		$option_values = array();

		foreach ( $options as $option_name => $option_value ) {
			$option_values[ $option_name ] = scf_get_option( $option_name, $option_value );
		}
		return $option_values;
	}
}

// scf render
if ( ! function_exists( 'scf_render' ) ) {
	function scf_render( $template, $data = array() ) {
		$template_path = SCF_TEMPLATE . '/' . $template . '.php';
		if ( file_exists( $template_path ) ) {
			extract( $data );
			include $template_path;
		}
	}
}


# is true 
if ( ! function_exists( 'scf_is_true' ) ) {
	function scf_is_true( $value ) {
		return ( $value === true || $value === 'true' || $value === 1 || $value === '1' );
	}
}

if(!function_exists('scf_is_dev')){
	function scf_is_dev(){
		return defined('WP_DEBUG') && WP_DEBUG;
	}
}